extract_archive_member_to_path

Function extract_archive_member_to_path 

fn extract_archive_member_to_path(
    archive_path: &Path,
    member_path: &str,
    destination: &Path,
) -> Result<(), Report>
Extracts a single archive member into destination.

This is used to pull only the configured zcashd binary from a release archive, rather than unpacking all members.