pub(super) fn managed_zcashd_binary_path(
state_cache_dir: &Path,
) -> Option<PathBuf>Expand description
Returns the managed zcashd binary cache path without creating directories,
or None when managed downloads are unsupported for this target.
Only called from Linux-gated preflight code, so it is dead code on other targets.